@@ -5,18 +5,34 @@ from __future__ import annotations
 import os
 import re
 import uuid
+from typing import TYPE_CHECKING
 from unittest.mock import MagicMock, patch
 
 import pytest
 
 from openlineage.client.client import OpenLineageClient
-from openlineage.client.run import Job, Run, RunEvent, RunState
+from openlineage.client.run import (
+    SCHEMA_URL,
+    Dataset,
+    DatasetEvent,
+    Job,
+    JobEvent,
+    Run,
+    RunEvent,
+    RunState,
+)
+
+if TYPE_CHECKING:
+    from pathlib import Path
 
 
 def test_client_fails_with_wrong_event_type() -> None:
     client = OpenLineageClient(url="http://example.com", session=MagicMock())
 
-    with pytest.raises(ValueError, match="`emit` only accepts RunEvent class"):
+    with pytest.raises(
+        ValueError,
+        match="`emit` only accepts RunEvent, DatasetEvent, JobEvent class",
+    ):
         client.emit("event")
 
 
@@ -51,7 +67,7 @@ def test_client_passes_to_create_with_valid_url(url: str, res: str) -> None:
     assert OpenLineageClient(url=url, session=MagicMock()).transport.url == res
 
 
-def test_client_sends_proper_json_with_minimal_event() -> None:
+def test_client_sends_proper_json_with_minimal_run_event() -> None:
     session = MagicMock()
     client = OpenLineageClient(url="http://example.com", session=session)
 
@@ -70,7 +86,55 @@ def test_client_sends_proper_json_with_minimal_event() -> None:
         '{"eventTime": "2021-11-03T10:53:52.427343", "eventType": "START", "inputs": [], "job": '
         '{"facets": {}, "name": "job", "namespace": "openlineage"}, "outputs": [], '
         '"producer": "producer", "run": {"facets": {}, "runId": '
-        '"69f4acab-b87d-4fc0-b27b-8ea950370ff3"}}',
+        f'"69f4acab-b87d-4fc0-b27b-8ea950370ff3"}}, "schemaURL": "{SCHEMA_URL}"}}',
+        timeout=5.0,
+        verify=True,
+    )
+
+
+def test_client_sends_proper_json_with_minimal_dataset_event() -> None:
+    session = MagicMock()
+    client = OpenLineageClient(url="http://example.com", session=session)
+
+    client.emit(
+        DatasetEvent(
+            eventTime="2021-11-03T10:53:52.427343",
+            producer="producer",
+            schemaURL="datasetSchemaUrl",
+            dataset=Dataset(namespace="my-namespace", name="my-ds"),
+        ),
+    )
+
+    session.post.assert_called_with(
+        "http://example.com/api/v1/lineage",
+        '{"dataset": {"facets": {}, "name": "my-ds", '
+        '"namespace": "my-namespace"}, "eventTime": '
+        '"2021-11-03T10:53:52.427343", "producer": "producer", '
+        '"schemaURL": "datasetSchemaUrl"}',
+        timeout=5.0,
+        verify=True,
+    )
+
+
+def test_client_sends_proper_json_with_minimal_job_event() -> None:
+    session = MagicMock()
+    client = OpenLineageClient(url="http://example.com", session=session)
+
+    client.emit(
+        JobEvent(
+            eventTime="2021-11-03T10:53:52.427343",
+            schemaURL="jobSchemaURL",
+            job=Job("openlineage", "job"),
+            producer="producer",
+        ),
+    )
+
+    session.post.assert_called_with(
+        "http://example.com/api/v1/lineage",
+        '{"eventTime": "2021-11-03T10:53:52.427343", '
+        '"inputs": [], "job": {"facets": {}, "name": "job", "namespace": '
+        '"openlineage"}, "outputs": [], "producer": "producer", '
+        '"schemaURL": "jobSchemaURL"}',
         timeout=5.0,
         verify=True,
     )
@@ -88,6 +152,7 @@ def test_client_uses_passed_transport() -> None:
             Run("69f4acab-b87d-4fc0-b27b-8ea950370ff3"),
             Job("openlineage", "job"),
             "producer",
+            "schemaURL",
         ),
     )
     client.transport.emit.assert_called_once()
@@ -96,26 +161,27 @@ def test_client_uses_passed_transport() -> None:
 @pytest.mark.parametrize(
     ("name", "config_path", "should_emit"),
     [
-        ("job", "tests/config/exact_filter.yml", False),
-        ("wrong", "tests/config/exact_filter.yml", False),
-        ("job1", "tests/config/exact_filter.yml", True),
-        ("1wrong", "tests/config/exact_filter.yml", True),
-        ("asdf", "tests/config/exact_filter.yml", True),
-        ("", "tests/config/exact_filter.yml", True),
-        ("whatever", "tests/config/regex_filter.yml", False),
-        ("something_whatever_asdf", "tests/config/regex_filter.yml", False),
-        ("$$$.whatever", "tests/config/regex_filter.yml", False),
-        ("asdf", "tests/config/regex_filter.yml", True),
-        ("", "tests/config/regex_filter.yml", True),
+        ("job", "exact_filter.yml", False),
+        ("wrong", "exact_filter.yml", False),
+        ("job1", "exact_filter.yml", True),
+        ("1wrong", "exact_filter.yml", True),
+        ("asdf", "exact_filter.yml", True),
+        ("", "exact_filter.yml", True),
+        ("whatever", "regex_filter.yml", False),
+        ("something_whatever_asdf", "regex_filter.yml", False),
+        ("$$$.whatever", "regex_filter.yml", False),
+        ("asdf", "regex_filter.yml", True),
+        ("", "regex_filter.yml", True),
     ],
 )
 def test_client_filters_exact_job_name_events(
     name: str,
     config_path: str,
+    root: Path,
     *,
     should_emit: bool,
 ) -> None:
-    with patch.dict(os.environ, {"OPENLINEAGE_CONFIG": config_path}):
+    with patch.dict(os.environ, {"OPENLINEAGE_CONFIG": str(root / "config" / config_path)}):
         factory = MagicMock()
         transport = MagicMock()
         factory.create.return_value = transport
@@ -128,6 +194,7 @@ def test_client_filters_exact_job_name_events(
             run=run,
             job=Job(name=name, namespace=""),
             producer="",
+            schemaURL="",
         )
 
         client.emit(event)
